{-----------------------------------------------------------------}
{           Routines utilitaires diverses, de traitement          }
{           de chaines et numriques.                             }
{           Philippe GORMAND    Mars 2001                         }
{           URL :   http://philippe.gormand.free.fr               }
{-----------------------------------------------------------------}
unit Utilitaires;
       // Regroupe des routines utilitaires

interface

Uses
    Windows,SysUtils,Classes,Grids,Printers,Graphics;


Type
   EnsembleCarac  = Set of Char;
   TParamGrid     = Array[1..2] of Integer;


Function  ExtraitParametreProg(Var Nom : String) : String;
Function  ReductionChemin(Chemin : String) : String;
Function  CompleteChemin(Chemin : String) : String;
Function  CompteMots(S : String; WordDelims : EnsembleCarac) :	Integer;
Function  ExtraitMot(N : Integer;S : String;WordDelims : EnsembleCarac) : String;
Function  EffBlancs(Chn : String) : String;
Function  EffBlancsDebutEtFin(Chn : String) : String;
Function  ChnEnReel(S : String) : Double;
Function  ReelEnChn(V : Double;D : Byte) : String;
Function  ChaineEntierValide(Chn : String) : Boolean;
Function  ChaineReeleValide(Chn : String) : Boolean;
Procedure TrierListe(Liste : TStringList;Croissant : Boolean);
Function  BoolEnChn(Vrai : Boolean) : String;
Function  MotBin(W : word) : String;
Function  ChnBinEnOctet(ChnBin : String) : Byte;
Function  RemplaceCar(S : String;Ch1,Ch2 : Char) : String;
Function  MotHex(W : Word) : String;
Function  OctetHex(B :	Byte) :	String;
Function  HexCardinal(Hexa : String) : Cardinal;
Function  HexInteger(Hexa : String) : Integer;
Function  HexInt(Hexa : String) : SmallInt;
Function  OctetBin(B :	Byte) :	String;
Function  ChargeTableDansGrille(Nom : String;Grille : TStringGrid;
          Separateur : EnsembleCarac) : TParamGrid;
          // Retourne Nombre de colonne,Nombre de lignes.
          // Retourne -1,0 si le fichier n'existe pas.
          // Retourne -2,0 si erreur d'ouverture.
          // Retourne -3,0 si erreur de lecture;

Function  SauveGrilleDansTable(Nom : String;Grille : TStringGrid;
                               Separateur : Char) : Boolean;

Procedure ImprimeGrille(Grille : TStringGrid;Lignes : Integer;
                        NomCheminComplet,ChaineEntete : String);

Function  TexteCheminFichierValide(Chn : String;PP : Boolean) : Boolean;
Procedure WordHi(Var W: Word;O : Byte);
Procedure WordLo(Var W: Word;O : Byte);

implementation

Const
   Digits    : Array[0..$F] Of Char = '0123456789ABCDEF';


{--------------------------------------------------------}
{ Cette fonction retourne le paramtre de commande, et   }
{ renvoit le nom du programme sans le parametre dans Nom }
{ Exemple :                                              }
{        Nom:=ParamStr(0); (C:\Edition.exe Lisezmoi.txt) }
{        Parametre:=ExtraitParametreProg(Nom);           }
{        Nom contient C:\Edition.exe, et Parametre       }
{        contient Lisezmoi.txt                           }
{--------------------------------------------------------}
Function ExtraitParametreProg(Var Nom : String) : String;
Var
  Chn   : String;
  Index : Integer;

Begin
   Result:='';
   If Length(Nom) = 0 Then Exit;
   Chn:=UpperCase(Nom);
   Index:=Pos('.EXE',Chn);
   If (Index + 3) < Length(Chn) Then // Il y a un parametre
    begin
       Result:=Copy(Nom,Index + 5,Length(Nom) - Index + 4);
       Nom:=Copy(Nom,1,Index + 3);
    end;
End;
{--------------------------------------------------------}
{      Supprime la dernire occurance de rpertoir       }
{      Exemple :                                         }
{        Chemin:=ReductionChemin(C:\VALEURS\Temporaire); }
{        Chemin contient C:\VALEURS                      }
{--------------------------------------------------------}
Function ReductionChemin(Chemin : String) : String;
Begin
   Result:=Chemin;
   If Length(Chemin) < 3 Then Exit;
   If Chemin[Length(Chemin)] = '\' Then Delete(Chemin,Length(Chemin),1);
   If Length(Chemin) < 3 Then
    begin
       Result:=Chemin;
       Exit;
    end;
   If Chemin[Length(Chemin)] = ':' Then
    begin
       Result:=Chemin;
       Exit;
    end;
   Repeat
       Delete(Chemin,Length(Chemin),1);
   Until (Chemin[Length(Chemin)] = '\') Or (Chemin[Length(Chemin)] = ':');
   If Chemin[Length(Chemin)] = '\' Then Delete(Chemin,Length(Chemin),1);
   Result:=Chemin;
End;
{--------------------------------------------------------}
{   Ajoute un antislash  (\) au chemin si il manque      }
{--------------------------------------------------------}
Function  CompleteChemin(Chemin : String) : String;
Begin
   If Chemin[Length(chemin)] <> '\' Then
    Chemin:=Chemin + '\';
End;
{--------------------------------------------------------}
{ Compte le nombre de mots d'une phrase en utilisant     }
{ un ou plusieurs caractres sparateurs de champs       }
{ Exemple : Mots:=CompteMots(Chaine,[',',';',#9]);       }
{          Utilisation de la virgule, du point-virgule   }
{          et du tabulateur comme sparateur de champs   }
{--------------------------------------------------------}
Function CompteMots(S	: String; WordDelims : EnsembleCarac) :	Integer;
var
   I, Count : Integer;

begin
   If Length(S) = 0 Then Result:=0
    Else
     begin
        Count := 1;
        For I:=1 To Length(S) Do
         If (S[I] in WordDelims) Then Inc(Count);
        Result := Count;
     end;
end;
{--------------------------------------------------------}
{ Extrait le n mot d'une phrase en utilisant            }
{ un ou plusieurs caractres sparateurs de champs       }
{ Exemple : Mot:=ExtraitMot(5,Chaine,[',',';',#9]);      }
{          Utilisation de la virgule, du point-virgule   }
{          et du tabulateur comme sparateur de champs   }
{--------------------------------------------------------}
Function ExtraitMot(N : Integer;S : String;WordDelims : EnsembleCarac) : String;
var
    Chn       : String;
    I, Count  : Integer;
    LongRech  : Integer;

Begin
    Count := 0;
    I := 1;
    Chn:='';
    LongRech:=Length(S);
    S:=S + ' ';
    While (I <=	LongRech) And (Count <>	N) Do
     begin
        while (I < LongRech) and (S[I] in WordDelims) do Inc(I);

        if I <= LongRech then Inc(Count);
        while (I <= LongRech) And Not(S[I] in WordDelims) Do
         begin
            If Count = N Then  Chn:=Chn + S[I];
            Inc(I);
         end;
     end;
    Result:=Chn;
end;
{--------------------------------------------------------}
{  Supprime tous les espaces de la chaine de caractres  }
{--------------------------------------------------------}
Function EffBlancs(Chn : String) : String;
Var
  I   : Integer;
  S   : String;
Begin
   If Length(Chn) = 0 Then Exit;
   S := '';
   For I:=1 To Length(Chn) Do
    If Chn[I] <> #32 Then S:=S + Chn[I];
   Result:=S;
End;
{--------------------------------------------------------}
{  Supprime les espaces de debut et de fin de la chaine  }
{--------------------------------------------------------}
Function EffBlancsDebutEtFin(Chn : String) : String;
Var
  I,J   : Integer;
  S     : String;

Begin
   S:=Chn;
   If Length(S) <> 0 Then
    begin
       While S[1] = #32 Do
        If Length(S) > 1 Then Delete(S,1,1)
        Else
          begin
             S:='';
             Break;
          end;

        While S[Length(S)] = #32 Do
         If Length(S) > 1 Then Delete(S,Length(S),1)
         Else
          begin
             S:='';
             Break;
          end;
    end;
   Result:=S;
End;
{--------------------------------------------------------}
{        Conversion scurise d'une chaine en rel       }
{--------------------------------------------------------}
Function ChnEnReel(S : String) : Double;
Var
  I,R  : Integer;
  V    : Double;
Begin
   If Length(S) = 0 Then
    begin
       Result := 0;
       Exit;
    end;
   I := Pos(',',S);
   If I > 0 Then S[I] := '.';
   For I:=1 To Length(S) Do
    begin
       If Not (S[I] In['+','-','.','0'..'9']) Then
        begin
           Result:=0;
           Exit;
        end;
    end;
   Val(S,V,R);
   If R <> 0 Then Result:=0
   Else Result:=V;
end;
{-------------------------------------------------------------------}
{      Convertit un Reel sur 32 bits en chaine de caractres        }
{-------------------------------------------------------------------}
Function ReelEnChn(V : Double;D : Byte) : String;
Var
  S : String;
Begin
   Str(V:1:D,S);
   Result:=S;
End;
{-------------------------------------------------------------------}
{       Indique si une chaine de caractres reprsente une valeur   }
{       entire valide.                                             }
{-------------------------------------------------------------------}
Function ChaineEntierValide(Chn : String) : Boolean;
Var
  I  : Integer;
Begin
   Result:=False;
   If Length(Chn) = 0 Then Exit;
   For I:=1 To Length(Chn) Do
    If Not (Chn[I] In['0'..'9']) Then Exit;
   Result:=True;
End;
{-------------------------------------------------------------------}
{       Indique si une chaine de caractres reprsente une valeur   }
{        virgule flotante valide.                                  }
{-------------------------------------------------------------------}
Function ChaineReeleValide(Chn : String) : Boolean;
Var
  I  : Integer;

Begin
   Result:=False;
   If Length(Chn) = 0 Then Exit;
   I := Pos(',',Chn);
   If I > 0 Then Chn[I] := '.';
   For I:=1 To Length(Chn) Do
    If Not (Chn[I] In['-','0'..'9','.']) Then Exit;
   Result:=True;
End;
{-------------------------------------------------------------------}
{      Permet de trier une liste de chaine en ordre croissant ou    }
{      dcroissant.                                                 }
{      Exemple : TrierListe(ListeDechaines,False);                  }
{-------------------------------------------------------------------}
Procedure TrierListe(Liste : TStringList;Croissant : Boolean);
Var
   Valide,Ech  : Boolean;
   Tamp,
   Chn1,Chn2   : String;
   Ecart,I     : Integer;
   ListeTmp    : TstringList;

Begin
   If Liste.Count < 2 Then Exit;
   Liste.Sorted:=True;
   Liste.Sort;
   If Croissant Then Exit
   Else
    begin
       Liste.Sorted:=False;
       ListeTmp:=TStringList.Create;
       ListeTmp.Sorted:=False;
       For I:=Liste.Count - 1 DownTo 0 Do
        ListeTmp.Add(Liste.Strings[I]);
       Liste.Clear;
       For I:=0 To ListeTmp.Count Do
        Liste.Add(ListeTmp.Strings[I]);
       ListeTmp.Free;
    end
End;
{-------------------------------------------------------------------}
{           Convertit un booleen en chaine de caractres            }
{-------------------------------------------------------------------}
Function  BoolEnChn(Vrai : Boolean) : String;
Begin
   If Vrai Then Result:='Vrai'
   Else Result:='Faux';
End;
{-------------------------------------------------------------------}
{          Convertit une valeur numrique de type Word en sa        }
{          reprsentation binaire.                                  }
{-------------------------------------------------------------------}
Function MotBin(W : word) : String;
Var
   I,N : Word;
   Chn : String;

Begin
   N:=1;
   SetLength(Chn,16);
   For I:=15 DownTo 0 Do
    begin
       Chn[N]:=Digits[Ord(W And (1 Shl I) <> 0)]; {0 Or 1}
       Inc(N);
    end;
End;
{-------------------------------------------------------------------}
{          Convertit une valeur numrique de type Byte en sa        }
{          reprsentation binaire.                                  }
{-------------------------------------------------------------------}
Function OctetBin(B :	Byte) :	string;
Var
    I, N : Word;
  begin
    N := 1;
    OctetBin := '00000000';
    For	I := 7 DownTo 0	Do
     begin
        OctetBin[N] := Digits[Ord(B And (1 Shl I) <> 0)];{0 or 1}
        Inc(N);
     end;
  end;
{----------------------------------------------------------------}
{ Converti une chaine reprsentant un mot binaire                }
{        Ex: Valeur:=ChnBinEnOctet('00110010');                  }
{----------------------------------------------------------------}
Function ChnBinEnOctet(ChnBin : String) : Byte;

Var
   Octet,MsOctet,Bit : Byte;

Begin
   Octet:=0;
   MsOctet:=1;
   For bit:=1 To 8 Do
    begin
       Case ChnBin[9-Bit] Of
       '1':Octet:=Octet + MsOctet;
       End;
       MsOctet:=MsOctet * 2;
    end;
   ChnBinEnOctet:=Octet;
End;
{----------------------------------------------------------------}
{      Remplace tous caractres de la chaine = ch1 par ch2       }
{----------------------------------------------------------------}
Function RemplaceCar(S : String;Ch1,Ch2 : Char) : String;
Var
    L  : Byte;

Begin
   For L:=1 To Length(S) Do
     If S[L]=Ch1 Then S[L]:=Ch2;
   RemplaceCar:=S;
End;
{----------------------------------------------------------------}
{   Convertit une valeur de type Word, en sa reprsentation      }
{   hexadcimale. Exemple : Chn:=MotHex(255);                    }
{               Chn contient '00FF'                              }
{----------------------------------------------------------------}
Function MotHex(W : Word) : String;
  {-Retourne un Word Hexadcimale en chaine de caratres }
Begin
   MotHex := '0000';
   MotHex[1] := Digits[hi(W) shr 4];
   MotHex[2] := Digits[hi(W) and $F];
   MotHex[3] := Digits[lo(W) shr 4];
   MotHex[4] := Digits[lo(W) and $F];
End;
{----------------------------------------------------------------}
{   Convertit une valeur de type Byte, en sa reprsentation      }
{   hexadcimale. Exemple : Chn:=OctetHex(255);                  }
{               Chn contient 'FF'                                }
{----------------------------------------------------------------}
Function OctetHex(B :	Byte) :	String;
  {-Return hex string for byte}

begin
   OctetHex:='00';
   OctetHex[1]:= Digits[B shr	4];
   OctetHex[2]:= Digits[B and	$F];
end;
{----------------------------------------------------------------}
{  Convertit une chaine de caractres reprsentant une valeur    }
{  en hexadcimale, en valeur numrique de type Cardinal         }
{  32 bits non sign   0..4294967295	.                        }
{----------------------------------------------------------------}
Function HexCardinal(Hexa : String) : Cardinal;
Var
  I         : Byte;
  Somme,
  Chiffre   : Int64;
  Chn       : String;
  Car       : Char;

Begin
   Chn:='';
   Somme:=0;
   If Length(Hexa) >= 8 Then Chn:=Copy(Hexa,1,8);
   If Length(Hexa) < 8 Then
    While Length(Hexa) < 8 Do Hexa:='0' + Hexa;
   For I:=8 DownTo 1 Do
    begin
       Car:=Hexa[I];
       Chiffre:=0;
       If Car In['0'..'9'] Then Chiffre:=Ord(Car) - 48;
       If Car In['A'..'F'] Then Chiffre:=Ord(Car) - 55;
       Case I Of
       8:Somme:=Somme + Chiffre;
       7:Somme:=Somme + (Chiffre * 16);
       6:Somme:=Somme + (Chiffre * 256);
       5:Somme:=Somme + (Chiffre * 4096);
       4:Somme:=Somme + (Chiffre * 65536);
       3:Somme:=Somme + (Chiffre * 1048576);
       2:Somme:=Somme + (Chiffre * 16777216);
       1:Somme:=Somme + (Chiffre * 268435456);
       End;
    end;
  Result:=Somme;
End;
{----------------------------------------------------------------}
{  Convertit une chaine de caractres reprsentant une valeur    }
{  en hexadcimale, en valeur numrique de type Integer          }
{  32 bits sign   2147483648..2147483647.                      }
{----------------------------------------------------------------}
Function HexInteger(Hexa : String) : Integer;
Var
  Somme : Cardinal;
  V     : Int64;
Begin
   V:=HexCardinal(Hexa);
   V:=V - 2147483648;
   Result:=Integer(V);
End;
{----------------------------------------------------------------}
{  Convertit une chaine de caractres reprsentant une valeur    }
{  en hexadcimale, en valeur numrique de type                  }
{  Integer 16 bits  32768..32767	.                        }
{----------------------------------------------------------------}
Function HexInt(Hexa : String) : SmallInt;
Var
  I       : Byte;
  Somme,
  Chiffre   : Integer;
  Chn       : String;
  Car       : Char;

Begin
   Chn:='';
   Somme:=0;
   If Length(Hexa) >= 4 Then Chn:=Copy(Hexa,1,4);
   If Length(Hexa) < 4 Then
    While Length(Hexa) < 4 Do Hexa:='0' + Hexa;
   For I:=4 DownTo 1 Do
    begin
       Car:=Hexa[I];
       Chiffre:=0;
       If Car In['0'..'9'] Then Chiffre:=Ord(Car) - 48;
       If Car In['A'..'F'] Then Chiffre:=Ord(Car) - 55;
       Case I Of
       4:Somme:=Somme + Chiffre;
       3:Somme:=Somme + (Chiffre * 16);
       2:Somme:=Somme + (Chiffre * 256);
       1:Somme:=Somme + (Chiffre * 4096);
       End;
    end;
  Result:=SmallInt(Somme - 32768);
End;
{---------------------------------------------------------}
{ Charger le contenu d'un fichier tableur dans une grille }
{ Fonctionne avec un fichier texte dans lequel les        }
{ champs sont spars par un ou plusieurs caracters       }
{ spcifiques  Separateur -> [';',',',#9] par exemple     }
{---------------------------------------------------------}
Function  ChargeTableDansGrille(Nom : String;Grille : TStringGrid;
          Separateur : EnsembleCarac) : TParamGrid;
Var
   F       : TextFile;
   Chn     : String;
   C,L,M,I : Integer;

Begin
   If Not FileExists(Nom) Then
    begin
       Result[1]:=-1;
       Result[2]:=0;
       Exit;
    end;
   AssignFile(F,Nom);
   Reset(F);
   If IoResult <> 0 Then
    begin
       Result[1]:=-2;
       Result[2]:=0;
       Exit;
    end;
   C:=0;   L:=0;
   Grille.RowCount:=1;
   // La ligne 1, est rserve pour les lgendes.
   Repeat
       ReadLn(F,Chn);
       If IoResult = 0 Then
        begin
           Inc(L);
           Grille.RowCount:=L + 1;
           // Compter le nombre de mots
           M:=CompteMots(Chn,Separateur);
           If M > C Then
            begin
               C:=M;
               // Atribuer autant de colonnes que de mots par ligne
               // La colonne zro est rserve pour l'indexage.
               If Grille.ColCount < C + 1 Then Grille.ColCount:=C + 1;
            end;
           For I:=1 To M Do Grille.Cells[I,L]:=ExtraitMot(I,Chn,Separateur);
         end
        Else
         begin
            Result[1]:=-3;
            Result[2]:=0;
            Exit;
         end;
   Until Eof(F);
   CloseFile(F);
   Result[1]:=C;
   Result[2]:=L;
End;
{---------------------------------------------------------}
{ Enregistrer le contenu d'une StringGrid, dans un fichier}
{ fichier texte dans lequel les champs seront spars par }
{ un ou plusieurs caracters spcifiques. Ce type de       }
{ fichier est compatible avec EXCEL.                      }
{---------------------------------------------------------}
Function  SauveGrilleDansTable(Nom : String;Grille : TStringGrid;
                               Separateur : Char) : Boolean;
Var
   F         : TextFile;
   Chn,Mot   : String;
   C,L,M,I,J : Integer;

Begin
   Result:=True;
   If FileExists(Nom) Then
    begin
       If FileExists(ChangeFileExt(Nom,'.bak')) Then
        DeleteFile(ChangeFileExt(Nom,'.bak'));

       RenameFile(Nom,ChangeFileExt(Nom,'.bak'));
    end;
   AssignFile(F,Nom);
   Rewrite(F);
   C:=Grille.ColCount;
   L:=Grille.RowCount;
   For J:=1 To L Do
    begin
       Chn:='';
       For I:=1 To C Do  // Construire la chaine.
        begin
           Mot:=Grille.Cells[C,L];
           If Length(Mot) = 0 Then
            begin
               If Separateur <> #32 Then Mot:=#32
               Else Mot:='_';
            end;
           Chn:=Chn + Mot + Separateur;
         end;
        // Supprimer le dernier sparateur inutile.
        Delete(Chn,Length(Chn),1);
        // Ecrire la ligne dans le fichier
        WriteLn(F,Chn);
        If IoResult <> 0 Then
         begin
            Result:=False;
            Exit;
         end;
    end;
   CloseFile(F);
End;
{---------------------------------------------------------}
{                  Imprimmer un StringGrid                }
{---------------------------------------------------------}
Procedure ImprimeGrille(Grille : TStringGrid;Lignes : Integer;
                        NomCheminComplet,ChaineEntete : String);

var
  NbCol,NbLig,
  SCaleX,SCaleY,YL,
  HPolice,LPolice      : Integer;
  PDC                  : HDC;
  TR                   : TRect;

  Champs               : String[10];
  ChampsTete           : String[60];
  NbImpression,
  BaseX,
  BaseY,
  X,Y,XC               : Integer;
  Comp                 : Byte;

Const
   PixelsParPouce = 90;
   Espace ='          ';



Procedure IdentPrinter;
Begin
   Printer.BeginDoc;
   PDC:=Printer.Canvas.Handle;
   HPolice:=0;
   HPolice:=HPolice - Printer.Canvas.Font.Height;
   Printer.Canvas.Pen.Width:=3;
   ScaleX := GetDeviceCaps(PDC, LOGPIXELSX) div PixelsParPouce;
   ScaleY := GetDeviceCaps(PDC, LOGPIXELSY) div PixelsParPouce;
   LPolice:=HPolice - (SCaleX * 5);
end;

Procedure TraceCellule(Var PX,PY : Integer;Chaine : String;Gris : Boolean);
Var
  CLen,I    : Integer;
  Formate   : Word;
  C : Array[0..255] Of Char;

begin
   CLen:=Length(Chaine);
   TR.Left:=PX;
   TR.Top:=PY;
   TR.Right:=(PX + (LPolice * CLen));
   TR.Bottom:=(PY + HPolice + (SCaleY * 5));
   PDC:=Printer.Canvas.Handle;
   If Gris Then Printer.Canvas.Brush.Color:=clSilver
   Else Printer.Canvas.Brush.Style:=BsClear;
   Printer.Canvas.Pen.Color:=clSilver;
   Printer.Canvas.Rectangle(TR.Left,TR.Top,TR.Right,TR.Bottom);
   TR.Left:=TR.Left + SCaleX;
   TR.Top:=TR.Top + ScaleY;
   Formate:=DT_CENTER;
   StrPCopy(C,Chaine);
   Printer.Canvas.Font.color:=clBlack;
   If Not Gris Then DrawText(PDC,C,CLen,TR,Formate);
   PX:=TR.Right;
   PY:=TR.Bottom;
end;


begin
   NbCol:=Grille.colCount;
   NbLig:=Grille.RowCount;
   If Lignes < NbLig Then NbLig:=Lignes;
   BaseX:=50;
   BaseY:=250;
   IdentPrinter;
            { Imprimer les Donnes }
   X:=BaseX;
   ChampsTete:=ChaineEntete + '  ' + DateToStr(Date);
   For Comp:=Length(ChampsTete)  To 60 Do ChampsTete:=ChampsTete + ' ';
   TraceCellule(X,BaseY,ChampsTete,False);
   X:=BaseX;

   ChampsTete:='Identification : ' + NomCheminComplet;
   For Comp:=0 To 60 Do ChampsTete:=ChampsTete + ' ';
   TraceCellule(X,BaseY,ChampsTete,False);
   X:=BaseX;
   NbImpression:=0;
   ChampsTete:='';
   For Comp:=0 To 60 Do ChampsTete:=ChampsTete + ' ';
   TraceCellule(X,BaseY,ChampsTete,True);

   YL:=0;
   Repeat
    begin
       Inc(YL);
       X:=BaseX;
       For XC:=0 To (NbCol - 1) Do
        begin
           Champs:=Grille.Cells[XC,YL] + Espace;
           Y:=BaseY;
           TraceCellule(X,Y,Champs,False);
        end;

       Inc(NbImpression);
       BaseY:=Y;
       If (NbImpression = 40) Then
        begin
           NbImpression:=0;
           Printer.NewPage;
           BaseY:=250;
        end;
    end;
   Until (YL = (NbLig - 1));
   Printer.EndDoc;
end;
{--------------------------------------------------------------------}
{   Verifie si un ou plusieurs caractres invalides dans un nom de   }
{   dossier, sont prsents. PP autorise ou non plusieurs points.     }
{--------------------------------------------------------------------}
Function  TexteCheminFichierValide(Chn : String;PP : Boolean) : Boolean;
Var
   Points,I  : Integer;

Begin
   If Length(Chn) > 0 Then
    begin
       Points:=0;
       For I:=1 To Length(Chn) Do
        begin
           If (Chn[I] = '.') Then Inc(Points);
           If (Chn[I] In['/','-']) Or (Ord(Chn[I]) < 32) Or
              (Ord(Chn[I]) > 126) Or ((Points > 1) And Not PP) Then
            begin
               Result:= False;
               Break;
            end
           Else Result:=True;
        end;
    end
   Else Result := False;
End;

{----------------------------------------------------------------------}
Procedure WordHi(Var W: Word;O : Byte);
        { Place l'octet O dans le poids fort de la variable W }
Var
  L  : Byte;

Begin
   L:=Lo(W);
   W:=(O Shl 8) + L;
End;
{--------------------------------------------------------}
Procedure WordLo(Var W: Word;O : Byte);
        { Place l'octet O dans le poids faible de la variable W }
Var
  H : Byte;

Begin
   H:=Hi(W);
   W:=(H Shl 8) + O;
End;
end.
